==> haskell-bytestring-progress-1.4-12-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-progress.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-progress
version:              1.4
visibility:           public
id:                   bytestring-progress-1.4-5zOTLTl2M646B7ZFg0BwZS
key:                  bytestring-progress-1.4-5zOTLTl2M646B7ZFg0BwZS
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/bytestring-progress
synopsis:             A library for tracking the consumption of a lazy ByteString
description:
    In some cases, it is useful to know how fast a ByteString is being
    consumed. Typically, this could be to report some measure of progress
    to a waiting user, but it could also be to perform some form of testing
    on input / consumption code.

category:             Control
abi:                  56953b3c10abe8520ce40d6ebf0576a3
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Progress System.ProgressBar.ByteString

import-dirs:          /usr/lib/ghc-9.0.2/site-local/bytestring-progress-1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bytestring-progress-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-progress
hs-libraries:         HSbytestring-progress-1.4-5zOTLTl2M646B7ZFg0BwZS
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    terminal-progress-bar-0.4.1-1NDT4YYUuCMGSQw1a6S6D9 text-1.2.5.0
    time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-progress/html/bytestring-progress.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-progress/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-progress-1.4-29-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-progress.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-progress
version:              1.4
visibility:           public
id:                   bytestring-progress-1.4-CJVl9qoB6d8D3rnfoWUWOG
key:                  bytestring-progress-1.4-CJVl9qoB6d8D3rnfoWUWOG
license:              BSD-3-Clause
maintainer:           Adam Wick <awick@uhsure.com>
author:               Adam Wick <awick@uhsure.com>
homepage:             http://github.com/acw/bytestring-progress
synopsis:             A library for tracking the consumption of a lazy ByteString
description:
    In some cases, it is useful to know how fast a ByteString is being
    consumed. Typically, this could be to report some measure of progress
    to a waiting user, but it could also be to perform some form of testing
    on input / consumption code.

category:             Control
abi:                  f8033b21bf41a28faf05fbff7d71375d
exposed:              True
exposed-modules:
    Data.ByteString.Lazy.Progress System.ProgressBar.ByteString

import-dirs:          /usr/lib/ghc-9.0.2/site-local/bytestring-progress-1.4
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bytestring-progress-1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-progress
hs-libraries:         HSbytestring-progress-1.4-CJVl9qoB6d8D3rnfoWUWOG
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    terminal-progress-bar-0.4.2-EVFRE4YaGsk6P6oWvSOjjJ text-1.2.5.0
    time-1.9.3

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-progress/html/bytestring-progress.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-progress/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
